@@ -76,7 +76,9 @@ impl Contact {
         msg: Vec<u8>,
         mode: BroadcastMode,
     ) -> Result<TxResponse, CosmosGrpcError> {
-        let mut txrpc = TxServiceClient::connect(self.get_url()).await?;
+        let mut txrpc = TxServiceClient::connect(self.get_url())
+            .await?
+            .accept_gzip();
         let response = txrpc
             .broadcast_tx(BroadcastTxRequest {
                 tx_bytes: msg,
@@ -191,7 +193,9 @@ impl Contact {
         private_key: PrivateKey,
     ) -> Result<SimulateResponse, CosmosGrpcError> {
         let our_address = private_key.to_address(&self.chain_prefix).unwrap();
-        let mut txrpc = TxServiceClient::connect(self.get_url()).await?;
+        let mut txrpc = TxServiceClient::connect(self.get_url())
+            .await?
+            .accept_gzip();
 
         let fee_obj = Fee {
             amount: vec![],
